@@ -1,9 +1,9 @@
-use std::{env, fs, io};
+use std::{env, fs, io, path};
 
 use once_cell::sync::OnceCell;
 use serde::Deserialize;
 
-const CONFIG_FILE: &str = "configs/dc-testconn-config.toml";
+// const CONFIG_FILE: &str = "configs/dc-testconn-config.toml";
 
 #[derive(Deserialize, Debug)]
 pub struct Config {
@@ -20,17 +20,16 @@ impl Config {
         CONFIG.get().expect("Config is not initialized")
     }
 
-    fn from_file() -> Result<Config, std::io::Error> {
-        let config =
-            fs::read_to_string(CONFIG_FILE).expect("Something went wrong reading the file");
+    fn from_file(p: &str) -> Result<Config, std::io::Error> {
+        let config = fs::read_to_string(p).expect("Something went wrong reading the file");
         let config: Config = toml::from_str(&config).unwrap();
         print!("{:#?}", &config);
         Ok(config)
     }
 }
 
-pub fn config_init() {
-    let mut _config = Config::from_file().unwrap();
+pub fn config_init(file: &str) {
+    let mut _config = Config::from_file(file).unwrap();
 
     CONFIG.set(_config).unwrap();
 }
